/* -------------------------------------------------------------------
   File "movmagdyn.pro"

   This file defines the problem dependent data structures for the
   dynamic core-inductor problem.
           
   Altogether
   		getdp movmagdyn -solve MagDyn_t_av_2D -pos MapDyn_a -bin
   		        
   ------------------------------------------------------------------- */

ri = 50e-3;
ro = 70e-3;  
   

Group {

  Air    = Region[ 200 ];   
  AirInf = Region[ 210 ];
  Mag    = Region[ 100 ];

  SurfaceGh0  = Region[ 1100 ];  
  SurfaceGInf = Region[ 1102 ];
  
  Val_Rint = ri;
  Val_Rext = ro;

  DomainCC_Mag = Region[ {Air, AirInf} ];
  DomainC_Mag  = Region[ {Mag} ]; // Magnet
  DomainM_Mag  = Region[ {Mag} ];
  DomainE_Mag  = Region[ {Mag} ]; // Possibility of eddy currents
  DomainV_Mag  = Region[ {Mag} ];
  DomainInf    = Region[ {AirInf} ];
  Domain_Mag   = Region[ {DomainCC_Mag, DomainC_Mag} ];
}

Function {

  mu0 = 4.e-7 * Pi;
  mur = 1.05;

  mu [ #{Air, AirInf} ]  = mu0;
  mu [ #{Mag} ] = mur * mu0;  
  nu [ #{Air, AirInf} ]  = 1. / mu0;
  nu [ #{Mag} ] = 1. / ( mur * mu0 );

  hc[ Mag ] =  Vector[ -1000e3, 0., 0. ];
  
  sigma [ Mag ]  = 1e6;
  
  Freq = 1;
  nStep = 16;
  Mag_Time0 = 0.;
  Mag_TimeMax = 2 / Freq;
  Mag_DTime = Mag_TimeMax / nStep;
  Mag_Theta = 1;  
  
  v0 = 1;
  TimeFctSin[] = F_Sin_wt_p [] {2.*Pi*1/Mag_TimeMax*2, 0};
  velocity[ #{ Mag } ] = v0 * TimeFctSin[] * Vector[ 0.0, -1.0, 0.0 ];
}

Constraint {

  { Name MagneticVectorPotential_2D;
    Case {
      { Region SurfaceGh0 ; Value 0.; }
      { Region SurfaceGInf; Value 0.; }
      { Region Domain_Mag; Type InitFromResolution; NameOfResolution MagSta_a_2D; }
    }
  }
  
  { Name Current_2D;
    Case {

    }
  }
  { Name Voltage_2D;
    Case {
      { Region Mag; Value 0.; }
    }
  }     
}

Include "Jacobian_Lib.pro"
Include "Integration_Lib.pro"
Include "MagDyn_av_2D.pro"

PostOperation {
  { Name MapDyn_a; NameOfPostProcessing MagDyn_av_2D;
    Operation {
      Print[ az, 		OnElementsOf Domain_Mag,  File "Core_m_a.pos",  TimeStep{ (nStep/2):nStep-1 } ];
      Print[ j,  		OnElementsOf Domain_Mag,  File "Core_m_j.pos",	TimeStep{ (nStep/2):nStep-1 } ];
      Print[ b,  		OnElementsOf Domain_Mag,  File "Core_m_b.pos",	TimeStep{ (nStep/2):nStep-1 } ];
    }
  }          
}



